package com.ruoyi.system.controller;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.system.domain.dto.DockerLogsParams;
import java.util.ArrayList;
import com.ruoyi.system.domain.dto.UpdateBaseParams;
import com.ruoyi.system.domain.dto.DeploySSLParams;
import com.ruoyi.common.core.utils.StringUtils;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import com.ruoyi.common.core.web.domain.AjaxResult;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.bind.annotation.GetMapping;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.github.pagehelper.PageInfo;
import java.util.List;
import com.ruoyi.common.core.utils.bean.BeanUtils;
import com.ruoyi.system.domain.dto.SnServerDto;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.system.domain.SnServer;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.service.ISnServerService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.core.web.controller.BaseController;

@RestController
@RequestMapping({ "/SnServer" })
public class SnServerController extends BaseController
{
    @Autowired
    private ISnServerService snServerService;
    
    @RequiresPermissions({ "system:SnServer:list" })
    @GetMapping({ "/list" })
    public TableDataInfo list(final SnServer snServer) {
        this.startPage();
        final List<SnServer> list = this.snServerService.selectSnServerList(snServer);
        final TableDataInfo rspData = new TableDataInfo();
        rspData.setCode(200);
        rspData.setRows(BeanUtils.copyList((List)list, (Class)SnServerDto.class));
        rspData.setMsg("查询成功");
        rspData.setTotal(new PageInfo((List)list).getTotal());
        return rspData;
    }
    
    @RequiresPermissions({ "system:SnServer:export" })
    @Log(title = "服务器", businessType = BusinessType.EXPORT)
    @PostMapping({ "/export" })
    public void export(final HttpServletResponse response, final SnServer snServer) {
        final List<SnServer> list = this.snServerService.selectSnServerList(snServer);
        final ExcelUtil<SnServerDto> util = (ExcelUtil<SnServerDto>)new ExcelUtil((Class)SnServerDto.class);
        util.exportExcel(response, BeanUtils.copyList((List)list, (Class)SnServerDto.class), "服务器列表数据");
    }
    
    @RequiresPermissions({ "system:SnServer:query" })
    @GetMapping({ "/{serverId}" })
    public AjaxResult getInfo(@PathVariable("serverId") final Long serverId) {
        return this.success(BeanUtils.copy((Object)this.snServerService.selectSnServerByServerId(serverId), (Class)SnServerDto.class));
    }
    
    @RequiresPermissions({ "system:SnServer:add" })
    @Log(title = "服务器", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody final SnServer snServer) {
        return this.snServerService.insertSnServer(snServer);
    }
    
    @RequiresPermissions({ "system:SnServer:edit" })
    @Log(title = "服务器", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody final SnServer snServer) {
        return this.toAjax(this.snServerService.updateSnServer(snServer));
    }
    
    @RequiresPermissions({ "system:SnServer:remove" })
    @Log(title = "服务器", businessType = BusinessType.DELETE)
    @DeleteMapping({ "/{serverIds}" })
    public AjaxResult remove(@PathVariable final Long[] serverIds) {
        if (serverIds.length > 1) {
            return AjaxResult.error("服务器只能单个删除");
        }
        return this.toAjax(this.snServerService.deleteSnServerByServerIds(serverIds));
    }
    
    @RequiresPermissions({ "system:SnServer:deployBasic" })
    @Log(title = "部署服务器基础环境", businessType = BusinessType.OTHER)
    @PostMapping({ "/deployBasicEnv" })
    public AjaxResult deployBasicEnv(@RequestBody final SnServer snServer) {
        if (StringUtils.isEmpty(snServer.getDomain())) {
            return this.error("请先填写域名");
        }
        if (snServer.getServerId() == null) {
            return this.error("服务器ID不能为空");
        }
        return this.snServerService.deployBasicEnv(snServer);
    }
    
    @RequiresPermissions({ "system:SnServer:changeDomain" })
    @Log(title = "更换基础环境域名", businessType = BusinessType.OTHER)
    @PostMapping({ "/changeDomain" })
    public AjaxResult changeDomain(@RequestBody final SnServer snServer) {
        if (StringUtils.isEmpty(snServer.getDomain())) {
            return this.error("请先填写域名");
        }
        if (snServer.getServerId() == null) {
            return this.error("服务器ID不能为空");
        }
        return this.snServerService.changeDomain(snServer);
    }
    
    @RequiresPermissions({ "system:SnServer:deployDomainSSL" })
    @Log(title = "部署基础环境ssl证书", businessType = BusinessType.OTHER)
    @PostMapping({ "/deployDomainSSL" })
    public AjaxResult deployDomainSSL(@RequestBody final DeploySSLParams params) {
        if (params.getId() == null) {
            return this.error("服务器ID不能为空");
        }
        if (params.getType() == null) {
            return this.error("证书类型不能为空");
        }
        if (params.getType() != 1 && params.getType() != 2) {
            return this.error("证书类型有误");
        }
        if (params.getType() == 2 && StringUtils.isEmpty(params.getSslKey())) {
            return this.error("请先填写域名");
        }
        if (params.getType() == 2 && StringUtils.isEmpty(params.getSslPem())) {
            return this.error("请先填写域名");
        }
        return this.snServerService.deployDomainSSL(params);
    }
    
    @RequiresPermissions({ "system:SnServer:updateUI" })
    @Log(title = "更新基础环境UI包", businessType = BusinessType.OTHER)
    @PostMapping({ "/updateUI" })
    public AjaxResult updateUI(@RequestBody final UpdateBaseParams params) {
        if (params.getId() == null) {
            return this.error("服务器ID不能为空");
        }
        return this.snServerService.updateUI(params);
    }
    
    @RequiresPermissions({ "system:SnServer:updateBack" })
    @Log(title = "更新基础环境后台版本", businessType = BusinessType.OTHER)
    @PostMapping({ "/updateBack" })
    public AjaxResult updateBack(@RequestBody final UpdateBaseParams params) {
        if (params.getId() == null) {
            return this.error("服务器ID不能为空");
        }
        return this.snServerService.updateBack(params);
    }
    
    @RequiresPermissions({ "system:SnServer:updateServer" })
    @Log(title = "更新基础服务版本", businessType = BusinessType.OTHER)
    @PostMapping({ "/updateServer" })
    public AjaxResult updateServer(@RequestBody final UpdateBaseParams params) {
        if (params.getId() == null) {
            return this.error("服务器ID不能为空");
        }
        if (StringUtils.isEmpty(params.getServeName())) {
            return this.error("服务名称不能为空");
        }
        return this.snServerService.updateMessage(params);
    }
    
    @RequiresPermissions({ "system:SnServer:ddlUpdate" })
    @Log(title = "数据库表结构更新", businessType = BusinessType.OTHER)
    @PostMapping({ "/ddlUpdate" })
    public AjaxResult ddlUpdate(@RequestBody final UpdateBaseParams params) {
        if (params.getId() == null) {
            return this.error("服务器ID不能为空");
        }
        return this.snServerService.DDLUpdate(params.getId());
    }
    
    @RequiresPermissions({ "system:SnServer:syncUa" })
    @Log(title = "同步爬虫UA库", businessType = BusinessType.OTHER)
    @PostMapping({ "/syncUa" })
    public AjaxResult syncUa(@RequestBody final UpdateBaseParams params) {
        if (params.getId() == null) {
            return this.error("服务器ID不能为空");
        }
        return this.snServerService.syncUa(params.getId());
    }
    
    @RequiresPermissions({ "system:SnServer:syncUaAll" })
    @Log(title = "同步所有服务器爬虫UA库", businessType = BusinessType.OTHER)
    @PostMapping({ "/syncUaAll" })
    public AjaxResult syncUaAll() {
        return this.snServerService.syncUaAll((List)new ArrayList());
    }
    
    @RequiresPermissions({ "system:SnServer:getLogs" })
    @PostMapping({ "/getLogs" })
    public AjaxResult getLogs(@RequestBody final DockerLogsParams params) {
        if (params.getId() == null) {
            return this.error("服务器ID不能为空");
        }
        return this.snServerService.getLogs(params);
    }
    
    @RequiresPermissions({ "system:SnServer:getConfig" })
    @PostMapping({ "/getConfig" })
    public AjaxResult getConfig(@RequestBody final DockerLogsParams params) {
        if (params.getId() == null) {
            return this.error("服务器ID不能为空");
        }
        final SnServer server = this.snServerService.selectSnServerByServerId(params.getId());
        final JSONObject data = new JSONObject().fluentPut("ip", (Object)server.getIp()).fluentPut("port", (Object)server.getPort()).fluentPut("userName", (Object)server.getUserName()).fluentPut("password", (Object)server.getDePassword());
        return AjaxResult.success((Object)data);
    }
}
